@@ -1,11 +1,9 @@
 package Net::Kubernetes;
-$Net::Kubernetes::VERSION = '0.07';
+$Net::Kubernetes::VERSION = '0.08';
 use Moose;
-use Data::Dumper;
 require Net::Kubernetes::Namespace;
 require LWP::UserAgent;
 require HTTP::Request;
-require JSON;
 require URI;;
 require Throwable::Error;
 use MIME::Base64;
@@ -19,7 +17,7 @@ Net::Kubernetes
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 This package provides an object oriented interface to the REST API's provided by kubernetes.
 
