@@ -1,8 +1,9 @@
 package Net::Kubernetes::Role::APIAccess;
-$Net::Kubernetes::Role::APIAccess::VERSION = '0.07';
+$Net::Kubernetes::Role::APIAccess::VERSION = '0.08';
 use Moose::Role;
 require LWP::UserAgent;
 require HTTP::Request;
+use JSON::MaybeXS;
 require Cpanel::JSON::XS;
 require URI;
 use MIME::Base64;
@@ -13,7 +14,7 @@ Net::Kubernetes::Role::APIAccess
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =cut
 
@@ -59,7 +60,7 @@ has token => (
 
 has 'json' => (
     is       => 'ro',
-    isa      => 'Cpanel::JSON::XS',
+    isa      => JSON::MaybeXS::JSON,
     required => 1,
     lazy     => 1,
     builder  => '_build_json',
@@ -98,7 +99,7 @@ sub _build_lwp_agent {
 }
 
 sub _build_json {
-    return Cpanel::JSON::XS->new->allow_blessed(1)->convert_blessed(1);
+    return JSON::MaybeXS->new->allow_blessed(1)->convert_blessed(1);
 }
 
 sub create_request {
